package com.aucma.production.service;

import java.util.List;

import com.aucma.production.domain.ProdOrderNote;

public interface IProdOrderNoteService {
    ProdOrderNote selectProdOrderNoteByObjId(Long objId);

    List<ProdOrderNote> selectProdOrderNoteList(ProdOrderNote prodOrderNote);

    int insertProdOrderNote(ProdOrderNote prodOrderNote);

    int updateProdOrderNote(ProdOrderNote prodOrderNote);

    int deleteProdOrderNoteByObjIds(Long[] objIds);
}
