package com.aucma.production.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.production.domain.ProdOrderNote;
import com.aucma.production.service.IProdOrderNoteService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

@RestController
@RequestMapping("/production/orderNote")
public class ProdOrderNoteController extends BaseController {
    @Autowired
    private IProdOrderNoteService prodOrderNoteService;

    @PreAuthorize("@ss.hasPermi('production:orderNote:list')")
    @GetMapping("/list")
    public TableDataInfo list(ProdOrderNote prodOrderNote) {
        startPage();
        List<ProdOrderNote> list = prodOrderNoteService.selectProdOrderNoteList(prodOrderNote);
        return getDataTable(list);
    }

    @PreAuthorize("@ss.hasPermi('production:orderNote:export')")
    @Log(title = "工单备注与异常记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ProdOrderNote prodOrderNote) {
        List<ProdOrderNote> list = prodOrderNoteService.selectProdOrderNoteList(prodOrderNote);
        ExcelUtil<ProdOrderNote> util = new ExcelUtil<ProdOrderNote>(ProdOrderNote.class);
        util.exportExcel(response, list, "工单备注与异常记录数据");
    }

    @PreAuthorize("@ss.hasPermi('production:orderNote:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(prodOrderNoteService.selectProdOrderNoteByObjId(objId));
    }

    @PreAuthorize("@ss.hasPermi('production:orderNote:add')")
    @Log(title = "工单备注与异常记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ProdOrderNote prodOrderNote) {
        prodOrderNote.setCreatedBy(getUsername());
        return toAjax(prodOrderNoteService.insertProdOrderNote(prodOrderNote));
    }

    @PreAuthorize("@ss.hasPermi('production:orderNote:edit')")
    @Log(title = "工单备注与异常记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ProdOrderNote prodOrderNote) {
        prodOrderNote.setUpdatedBy(getUsername());
        return toAjax(prodOrderNoteService.updateProdOrderNote(prodOrderNote));
    }

    @PreAuthorize("@ss.hasPermi('production:orderNote:remove')")
    @Log(title = "工单备注与异常记录", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(prodOrderNoteService.deleteProdOrderNoteByObjIds(objIds));
    }
}
